@@ -36,7 +36,7 @@
 #######################
 
 locate <-
-function(x,xlu=NaN,no.col=FALSE,standard=TRUE,col=1,lty=1,bty="l",pty="s",las=1,adj=0.5,cex=1,cex.lab=0.8,cex.axis=0.8,xlab=c("Stretch Vector","Stretch Vector"),ylab=c("Parameter Setting","Predicted Response"),...)
+function(x,ncom=1,xlu=NULL,no.col=FALSE,standard=TRUE,col=1,lty=1,bty="l",pty="s",las=1,adj=0.5,cex=1,cex.lab=0.8,cex.axis=0.8,xlab=c("Stretch Vector","Stretch Vector"),ylab=c("Parameter Setting","Predicted Response"),...)
 {  
     ## Setting Values
     out<-x
@@ -51,17 +51,49 @@ function(x,xlu=NaN,no.col=FALSE,standard=TRUE,col=1,lty=1,bty="l",pty="s",las=1,
     deviation<-out[[3]]
     tau<-out[[5]]  
     tau1<-out[[6]] 
-  
-    if(!is.nan(xlu))
+
+    if(no.col==FALSE)
     {
-      if(xlu<1 || xlu>numbW)
+      ## Setting Values
+      cols<-1:(nx+ny)
+      if((nx+ny)>=7)
+      {
+        cols<-1:(nx+ny+1)
+        cols<-cols[-7]
+      }
+      ltys<-rep(1,nx+ny)
+    }
+    if(no.col==TRUE)
+    {
+      col1<-gray(seq(0.2,0.5,length=nx))
+      col2<-gray(seq(0.2,0.5,length=ny))
+      cols<-c(col1,col2)
+      ltys<-c(1:nx,1:ny)
+    }
+    if(no.col!=TRUE && no.col!=FALSE)
+    {
+      return(cat("no.col has to be logical!\n"))
+    }
+    if(length(col)==1)
+    col<-cols
+    if(length(lty)==1)
+    lty<-ltys
+    if(length(col)!=(nx+ny))
+    col<-cols
+    if(length(lty)!=(nx+ny))
+    lty<-ltys
+  
+  
+    if(!is.null(xlu))
+    {
+      if(any(xlu<1) || any(xlu>numbW))
       {
         cat("Choose a x-coordinate between 1 and numbW")
         cat("\n")
         return("Call locate again!")
       }
     }
-    if(is.nan(xlu))
+    if(is.null(xlu))
     {
       cat("Choose your preferred point on the right plot please!\n")
       cat("\n")
@@ -69,61 +101,39 @@ function(x,xlu=NaN,no.col=FALSE,standard=TRUE,col=1,lty=1,bty="l",pty="s",las=1,
     }
   
   
-    plot(out,no.col,standard,col,lty,bty,pty,las,adj,cex,cex.lab,cex.axis,xlab,ylab,...) 
+    plot(x=out,no.col=no.col,standard=standard,col=col,lty=lty,bty=bty,pty=pty,las=las,adj=adj,cex=cex,cex.lab=cex.lab,cex.axis=cex.axis,xlab=xlab,ylab=ylab,...) 
   
 
     ####
     ####  Location of points
     ####
 
-   
-    if(is.nan(xlu))
+
+    if(is.null(xlu))
     {
-      locp<-locator(n=1)
-      xloc1<-round(c(locp$x,locp$x))  
+      if(!is.wholenumber(ncom))
+      {
+        return("Number of preferenced compromises has to be an integer!\n")
+      }
+      locp<-locator(n=ncom)
+      xloc1<-round(locp$x)  
     }
-    if(!is.nan(xlu))
+    if(!is.null(xlu))
     {
-      xloc1<-c(xlu,xlu)  
+      if(any(!is.wholenumber(xlu)))
+      {
+        return("The entries of xlu have to be integers!\n")
+      }
+      xloc1<-xlu  
     }
       
     ## Chosen Points:
-    xl<-xloc1[1]
-    optp<-optmatrix[xl,]
-    reoptp<-reoptmatrix[xl,]
+    xlp<-xloc1
+    optp<-optmatrix[xloc1,]
+    reoptp<-reoptmatrix[xloc1,]
     ## Values to label the axes
     xaxis1<-1:numbW
     yaxis1<-seq(-round(max(abs(optmatrix)),digits=2+countdig(max(abs(optmatrix)))),round(max(abs(optmatrix)),digits=2+countdig(max(abs(optmatrix)))),round(max(abs(optmatrix)),digits=2+countdig(max(abs(optmatrix)))))
-  if(no.col==FALSE)
-  {
-    ## Setting Values
-    cols<-1:(nx+ny)
-    if((nx+ny)>=7)
-    {
-      cols<-1:(nx+ny+1)
-      cols<-cols[-7]
-    }
-    ltys<-rep(1,nx+ny)
-  }
-  if(no.col==TRUE)
-  {
-    col1<-gray(seq(0.2,0.5,length=nx))
-    col2<-gray(seq(0.2,0.5,length=ny))
-    cols<-c(col1,col2)
-    ltys<-c(1:nx,1:ny)
-  }
-  if(no.col!=TRUE && no.col!=FALSE)
-  {
-    return(cat("no.col has to be logical!\n"))
-  }
-  if(length(col)==1)
-  col<-cols
-  if(length(lty)==1)
-  lty<-ltys
-  if(length(col)!=(nx+ny))
-  col<-cols
-  if(length(lty)!=(nx+ny))
-  lty<-ltys
 
     optplot<-matrix(NaN,ncol=nx,nrow=numbW)
     for(i in 1:nx)
@@ -131,25 +141,32 @@ function(x,xlu=NaN,no.col=FALSE,standard=TRUE,col=1,lty=1,bty="l",pty="s",las=1,
       optplot[,i]<-optmatrix[,i]-min(optmatrix[,i])
       for(j in 1:numbW)
       { 
-        optplot[j,i]<-optplot[j,i]/(max(optmatrix[,i])-min(optmatrix[,i]))
+        optplot[j,i]<-ifelse(numeq(max(optmatrix[,i]),min(optmatrix[,i]))==TRUE,0.5,optplot[j,i]/(max(optmatrix[,i])-min(optmatrix[,i])))
       }  
     }
-    par(fig=c(0,0.45,0.15,0.85),new=TRUE,bty="l",pty="s",las=1,adj=adj,...)
+    
+    par(fig=c(0,0.45,0.15,0.85),bty="l",pty="s",las=1,adj=adj,...)
     matplot(xaxis1,optplot,type="l",col=col[1:(nx)],lty=lty[1:(nx)],xlab=xlab[1],ylab="",ylim=c(0,1.25),xaxt="n",yaxt="n",cex.lab=cex.lab,...)
     mtext(ylab[1],side=3,at=1,cex=cex.lab)
     axis(1,at=c(1,1+(numbW-1)/2,numbW),labels=c(Wstart,Wstart+0.5*(Wend-Wstart),Wend),cex.axis=cex.axis)
     axis(2,at=c(0,0.5,1),labels=c("","",""),cex.axis=cex.axis)   
-        
-    for(i in 1:ny)
+    
+    abline(v=xlp)    
+    for(i in 1:nx)
     {
-      mtext(c(round(min(optmatrix[,i]),digits=2+countdig(min(optmatrix[,i]))),round(0.5*(max(optmatrix[,i])+min(optmatrix[,i])),digits=2+countdig(0.5*(max(optmatrix[,i])+min(optmatrix[,i])))),round(max(optmatrix[,i]),digits=2+countdig(max(optmatrix[,i])))),side=2,at=c(0-(i-1)*(cex.axis*3/4)*1.25/26,0.5-(i-1)*(cex.axis*3/4)*1.25/26,1-(i-1)*(cex.axis*3/4)*1.25/26),col=col[i],cex=cex.axis,line=1.2)
+      if(numeq(max(optmatrix[,i]),min(optmatrix[,i]))==TRUE)
+      {
+        mtext(c(round(min(optmatrix[,i])*0.75,digits=2+countdig(min(optmatrix[,i])*0.5)),round(1*(max(optmatrix[,i])),digits=2+countdig(1*(max(optmatrix[,i])))),round(1.25*max(optmatrix[,i]),digits=2+countdig(1.25*max(optmatrix[,i])))),side=2,at=c(0-(i-1)*(cex.axis*3/4)*1.25/26,0.5-(i-1)*(cex.axis*3/4)*1.25/26,1-(i-1)*(cex.axis*3/4)*1.25/26),col=col[i],cex=cex.axis,line=1.2)    
+      }
+      else
+      {
+        mtext(c(round(min(optmatrix[,i]),digits=2+countdig(min(optmatrix[,i]))),round(0.5*(max(optmatrix[,i])+min(optmatrix[,i])),digits=2+countdig(0.5*(max(optmatrix[,i])+min(optmatrix[,i])))),round(max(optmatrix[,i]),digits=2+countdig(max(optmatrix[,i])))),side=2,at=c(0-(i-1)*(cex.axis*3/4)*1.25/26,0.5-(i-1)*(cex.axis*3/4)*1.25/26,1-(i-1)*(cex.axis*3/4)*1.25/26),col=col[i],cex=cex.axis,line=1.2)
+      }
+      for(j in 1:length(xlp))
+      {
+        points(xlp[j],optplot[xlp[j],i],col="black",cex=cex)
+      }
     }
-
-    yloc1<-c(-max(abs(optmatrix)),max(abs(optmatrix)))
-    abline(v=xl,lty="solid")
-    xlp<-rep(xloc1,nx)
-    xlr<-rep(xloc1,ny)
-    matpoints(rep(xl,nx),optplot[xl,],col=cols[1:nx],cex=cex,pch=1)
     legend("topright",dimnames(out$Parameters)[[2]][1:nx],col=col[1:nx],lty=lty[1:nx],bty="n",cex=cex.lab)
  
   
@@ -186,8 +203,8 @@ function(x,xlu=NaN,no.col=FALSE,standard=TRUE,col=1,lty=1,bty="l",pty="s",las=1,
       for(j in 1:ny)
       {
         polygon(c(1:numbW,numbW:1,1),c(reoptminusdev[,j],reoptplusdev[length(reoptplusdev[,j]):1,j],reoptminusdev[1,j]),col=rgb(col2rgb(col[nx+j])[1]/255,col2rgb(col[nx+j])[2]/255,col2rgb(col[nx+j])[3]/255,alpha=0.1+j*0.2/ny),border=FALSE)
-      } 
-      for(i in 1:ny)
+      }
+      for(i in 1:ny)                                                                                                                 
       {
         mtext(c(round(min(c(reoptmatrix[,i]-deviation[,i],tau[i])),digits=2+countdig(min(c(reoptmatrix[,i]-deviation[,i],tau[i])))),round((max(c(reoptmatrix[,i]+deviation[,i],tau[i]))+min(c(reoptmatrix[,i]-deviation[,i],tau[i])))*0.5,digits=2+countdig((max(c(reoptmatrix[,i]+deviation[,i],tau[i]))+min(c(reoptmatrix[,i]-deviation[,i],tau[i])))*0.5)),round(max(c(reoptmatrix[,i]+deviation[,i],tau[i])),digits=2+countdig(max(c(reoptmatrix[,i]+deviation[,i],tau[i]))))),side=2,at=c(0-(i-1)*(cex.axis*3/4)*1.25/26,0.5-(i-1)*(cex.axis*3/4)*1.25/26,1-(i-1)*(cex.axis*3/4)*1.25/26),col=col[nx+i],lty=lty[nx+i],cex=cex.axis,line=1.2)  
       } 
@@ -262,7 +279,7 @@ function(x,xlu=NaN,no.col=FALSE,standard=TRUE,col=1,lty=1,bty="l",pty="s",las=1,
 
     
     yloc1<-c(0,1.25)
-    abline(v=xl,lty="solid")
+    abline(v=xlp,lty="solid")
     nam<-dimnames(out$Responses)[[2]]
     for(i in 1:length(nam))
     {
@@ -270,7 +287,10 @@ function(x,xlu=NaN,no.col=FALSE,standard=TRUE,col=1,lty=1,bty="l",pty="s",las=1,
     }
     for(i in 1:ny)
     {
-      points(xlp[i],reoptplot[xlp[i],i],col="black",cex=cex)#cols[nx+i],cex=3)
+      for(j in 1:length(xlp))
+      {
+        points(xlp[j],reoptplot[xlp[j],i],col="black",cex=cex)#cols[nx+i],cex=3)
+      }
     }
     legend("topright",nam,col=col[(nx+1):(nx+ny)],lty=lty[(nx+1):(nx+ny)],bty="n",cex=cex.lab)
   
